@@ -104,7 +104,7 @@ dialog_button_clicked_cb (GtkDialog *dialog,
 	switch (response_id) {
 	case GTK_RESPONSE_HELP:
 		gnome_help_display_desktop (NULL, "user-guide",
-					    "wgoscustlookandfeel.xml",
+					    "user-guide.xml",
 					    "goscustlookandfeel-39", &error);
 		if (error) {
 			GtkWidget *msg_dialog;
@@ -838,9 +838,6 @@ create_dialog (GtkWidget *window)
 	
 	gtk_container_add (GTK_CONTAINER (sw), pd->freedb_server);
 
-	g_signal_connect (G_OBJECT (pd->update), "clicked",
-			  G_CALLBACK (update_clicked), pd);
-
 	/* create the update server list button */
 	align = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
 
