@@ -15,7 +15,8 @@
 #include <gtk/gtkrange.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkoptionmenu.h>
-#include <gtk/gtkmessagedialog.h> 
+#include <gtk/gtkmessagedialog.h>
+#include <gdk/gdkkeysyms.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-about.h>
 #include <libgnome/gnome-help.h>
@@ -448,22 +449,30 @@ set_track_option_menu (GtkOptionMenu *menu,
 					   G_CALLBACK (skip_to_track), NULL);
 }
 
+/* set the window title
+ *   with the current artist (through gcd)
+ *   and the track title (through status' track index)
+ * FIXME: only called during PAUSE/PLAY state changes, while this
+ *        would make sense to be used during track changes too.
+ *        What is being done instead there ?
+ */
 static void
 set_window_track_title (GnomeCD *gcd,
 			GnomeCDRomStatus *status)
 {
 	int idx = status->track - 1;
-	const char *artist = "";
-	const char *track_name = "";
+	const char *artist = NULL;
+	const char *track_name = NULL;
 
 	if (gcd->disc_info) {
 		if (idx >= 0 && idx < gcd->disc_info->ntracks &&
 		    gcd->disc_info->track_info)
 			track_name = gcd->disc_info->track_info [idx]->name;
 
-		artist = gcd->disc_info->artist ? gcd->disc_info->artist : "";
+		artist = gcd->disc_info->artist;
 	}
 
+	gcd_debug ("track_title: setting artist %s, track_name %s", artist, track_name);
 	gnome_cd_set_window_title (gcd, artist, track_name);
 }
 
@@ -482,14 +491,11 @@ status_ok (GnomeCD *gcd,
 	/* Set the track menu on. */
 	gtk_widget_set_sensitive (gcd->tracks, TRUE);
 	
-	/* All buttons can be used when the tray is open,
-	   they should shut the tray. */
-	gtk_widget_set_sensitive (gcd->back_b, TRUE);
+	/* All buttons can be used when the state is ok */
 	gtk_widget_set_sensitive (gcd->rewind_b, TRUE);
 	gtk_widget_set_sensitive (gcd->play_b, TRUE);
 	gtk_widget_set_sensitive (gcd->stop_b, TRUE);
 	gtk_widget_set_sensitive (gcd->ffwd_b, TRUE);
-	gtk_widget_set_sensitive (gcd->next_b, TRUE);
 	gtk_widget_set_sensitive (gcd->eject_b, TRUE);
 
 	switch (status->audio) {
@@ -509,8 +515,11 @@ status_ok (GnomeCD *gcd,
 			gcd->current_image = gcd->pause_image;
 		}
 		/* Find out if the track has changed */
-		track = gtk_option_menu_get_history (GTK_OPTION_MENU (gcd->tracks));
-		if (track + 1 != status->track) {
+                /* FIXME: this would be a good place to call
+                   set_window_track_title instead.
+                   Also, gtk_option_menu_get_history is now deprecated. */
+		track = gtk_option_menu_get_history (GTK_OPTION_MENU (gcd->tracks)) + 1;
+		if (track != status->track) {
 			set_track_option_menu (GTK_OPTION_MENU (gcd->tracks),
 					       status->track);
 		}
@@ -626,11 +635,10 @@ status_ok (GnomeCD *gcd,
 		cd_display_set_line (CD_DISPLAY (gcd->display),
 				     CD_DISPLAY_LINE_TIME, "");
 		if (gcd->disc_info != NULL) {
+                        gcd_debug ("AUDIO_STOP: artist %s, title %s", gcd->disc_info->artist, gcd->disc_info->title);
 			gnome_cd_set_window_title (gcd,
-						   gcd->disc_info->artist ?
-						   gcd->disc_info->artist : "",
-						   gcd->disc_info->title ?
-						   gcd->disc_info->title : "");
+						   gcd->disc_info->artist,
+						   gcd->disc_info->title);
 		} else {
 			gnome_cd_set_window_title (gcd, NULL, NULL);
 		}
@@ -645,10 +653,9 @@ status_ok (GnomeCD *gcd,
 		cd_display_set_line (CD_DISPLAY (gcd->display),
 				     CD_DISPLAY_LINE_TIME, _("Disc error"));
 		if (gcd->disc_info != NULL) {
-			gnome_cd_set_window_title (gcd, gcd->disc_info->artist ?
-						   gcd->disc_info->artist : "",
-						   gcd->disc_info->title ?
-						   gcd->disc_info->title : "");
+                        gcd_debug ("AUDIO_ERROR: artist %s, title %s", gcd->disc_info->artist, gcd->disc_info->title);
+			gnome_cd_set_window_title (gcd, gcd->disc_info->artist,
+						   gcd->disc_info->title);
 		} else {
 			gnome_cd_set_window_title (gcd, NULL, NULL);
 		}
@@ -660,11 +667,10 @@ status_ok (GnomeCD *gcd,
 		
 	default:
 		if (gcd->disc_info != NULL) {
+                        gcd_debug ("default: artist %s, title %s", gcd->disc_info->artist, gcd->disc_info->title);
 			gnome_cd_set_window_title (gcd,
-						   gcd->disc_info->artist ?
-						   gcd->disc_info->artist : "",
-						   gcd->disc_info->title ?
-						   gcd->disc_info->title : "");
+						   gcd->disc_info->artist,
+						   gcd->disc_info->title);
 		} else {
 			gnome_cd_set_window_title (gcd, NULL, NULL);
 		}
@@ -699,6 +705,7 @@ status_ok (GnomeCD *gcd,
 	}
 }
 
+/* GnomeCDRom status-changed signal handler */
 void
 cd_status_changed_cb (GnomeCDRom *cdrom,
 		      GnomeCDRomStatus *status,
@@ -710,13 +717,22 @@ cd_status_changed_cb (GnomeCDRom *cdrom,
 	
 	switch (status->cd) {
 	case GNOME_CDROM_STATUS_OK:
+                /* does everything when the state is ok */
 		status_ok (gcd, status);
+                /* next is sensitive when this is not the last track */
 		if (status->track >= gcd->disc_info->ntracks)
                        gtk_widget_set_sensitive (gcd->next_b, FALSE);
+		else
+                       gtk_widget_set_sensitive (gcd->next_b, TRUE);
+                /* back is sensitive when it's not the first track and
+                   we're playing */
                if (status->track <= 1 && (status->audio == GNOME_CDROM_AUDIO_STOP || status->audio == GNOME_CDROM_AUDIO_COMPLETE))
                        gtk_widget_set_sensitive (gcd->back_b, FALSE);
+		else
+                       gtk_widget_set_sensitive (gcd->back_b, TRUE);
 		break;
-		
+
+        /* everything below are states where we're not playing */
 	case GNOME_CDROM_STATUS_NO_DISC:
 		if (gcd->disc_info != NULL) {
 			cddb_free_disc_info (gcd->disc_info);
@@ -746,6 +762,8 @@ cd_status_changed_cb (GnomeCDRom *cdrom,
 		if (gcd->disc_info != NULL) {
 			cddb_free_disc_info (gcd->disc_info);
 			gcd->disc_info = NULL;
+			/* we need to destroy the hashtable(cddb_cache) */
+			destroy_cache_hashTable();
 		}
 		
 		gtk_widget_set_sensitive (gcd->trackeditor_b, FALSE);
@@ -916,6 +934,52 @@ tray_icon_clicked (GtkWidget *widget, GdkEventButton *event, GnomeCD *gcd)
 	}
 }
 
+gboolean
+tray_icon_pressed (GtkWidget *widget, GdkEventKey *event, GnomeCD *gcd)
+{
+	if (event->keyval == GDK_space ||
+	    event->keyval == GDK_KP_Space ||
+	    event->keyval == GDK_Return ||
+	    event->keyval == GDK_KP_Enter) {
+		if (GTK_WIDGET_VISIBLE (gcd->window)) {
+			gtk_widget_hide (gcd->window);
+		} else {
+			gtk_widget_show (gcd->window);
+		}
+
+		return TRUE;
+	} else {
+		return FALSE;
+	}
+}
+
+gint
+tray_icon_expose (GtkWidget* widget, GdkEventExpose *event)
+{
+  /*
+   * Draw focus indication if the GtkEventBox has focus.
+   */
+  if (GTK_WIDGET_HAS_FOCUS (gtk_widget_get_parent (widget)))
+    {
+      gint focus_width, focus_pad;
+      gint x, y, width, height;
+
+      gtk_widget_style_get (widget,
+                            "focus-line-width", &focus_width,
+                            "focus-padding", &focus_pad,
+                            NULL);
+      x = widget->allocation.x + focus_pad;
+      y = widget->allocation.y + focus_pad;
+      width = widget->allocation.width -  2 * focus_pad;
+      height = widget->allocation.height - 2 * focus_pad;
+      gtk_paint_focus (widget->style, widget->window,
+                       GTK_STATE_NORMAL,
+                       &event->area, widget, "button",
+                       x, y, width, height);
+    }
+  return FALSE;
+}
+
 void
 open_preferences (GtkWidget *widget,
 		  GnomeCD *gcd)
@@ -1025,8 +1089,7 @@ volume_changed (GtkRange *range,
 	GError *error;
 
 	volume = gtk_range_get_value (range);
-
-	if (gnome_cdrom_set_volume (gcd->cdrom, (int) -volume, &error) == FALSE) {
+	if (gnome_cdrom_set_volume (gcd->cdrom, (int) volume, &error) == FALSE) {
 		gcd_warning ("Error setting volume: %s", error);
 		g_error_free (error);
 	}
