@@ -33,6 +33,9 @@ static char *cd_option_device = NULL;
 static gboolean cd_option_unique = FALSE;
 static gboolean cd_option_play = FALSE;
 
+/* if env var GNOME_CD_DEBUG is set,
+ * g_warning the given message, and if there was an error, the error message
+ */
 void
 gcd_warning (const char *message,
 	     GError *error)
@@ -44,6 +47,35 @@ gcd_warning (const char *message,
 	g_warning (message, error ? error->message : "(None)");
 }
 
+/* if env var GNOME_CD_DEBUG is set, g_print the given message */
+void
+gcd_debug (const gchar *format,
+           ...)
+{
+	va_list args;
+	gchar *string;
+
+	if (debug_mode == FALSE) {
+		return;
+	}
+	va_start (args, format);
+	string = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	g_print ("DEBUG: gnome-cd: %s\n", string);
+	g_free (string);
+}
+
+/*
+ * Sets the window title based on the passed artist and track name.
+ * If artist and track is NULL, then "CD Player" is displayed.
+ * If either one is NULL, display the other.
+ * If neither are NULL, display "(artist) - (title)"
+ *
+ * FIXME: it might be nice to change this function so that it takes
+ * artist, track, album, status, so we can decide better what to display.
+ * Right now, sometimes this is called with the disc title instead of
+ * the track title */
 void
 gnome_cd_set_window_title (GnomeCD *gcd,
 			   const char *artist,
@@ -52,11 +84,14 @@ gnome_cd_set_window_title (GnomeCD *gcd,
 	char *title;
 	const char *old_title;
 
-	if (artist == NULL ||
-	    track == NULL) {
+	if (artist == NULL && track == NULL) {
 		title = g_strdup (_("CD Player"));
+	} else if (artist == NULL) {
+		title = g_strdup (track);
+	} else if (track == NULL) {
+		title = g_strdup (artist);
 	} else {
-		title = g_strconcat (track, " - ", artist, NULL);
+		title = g_strconcat (artist, " - ", track, NULL);
 	}
 	/*
 	 * Call gtk_window_set_title only if the title has changed
@@ -283,11 +318,14 @@ window_destroy_cb (GtkWidget *window,
 {
 	GnomeCD *gcd = data;
 
+	/* Make sure we stop playing the cdrom first */
+	gnome_cdrom_stop(gcd->cdrom, NULL);
+
 	/* Before killing the cdrom object, do the shutdown on it */
 	if (gcd->preferences->stop_eject) {
 		gnome_cdrom_eject (gcd->cdrom, NULL);
 	}
-		
+
 	/* Unref the cddb slave */
 	cddb_close_client ();
 
@@ -537,6 +575,8 @@ init_player (const char *device_override)
 			  G_CALLBACK (loopmode_changed_cb), gcd);
 	g_signal_connect (G_OBJECT (gcd->display), "playmode-changed",
 			  G_CALLBACK (playmode_changed_cb), gcd);
+	g_signal_connect (G_OBJECT (gcd->display), "style_set",
+			  G_CALLBACK (cd_display_set_style), NULL);
 
 	/* Theme needs to be loaded after the display is created */
 	gcd->theme = (GCDTheme *)theme_load (gcd, gcd->preferences->theme_name);
@@ -552,8 +592,9 @@ init_player (const char *device_override)
 	gtk_box_pack_start (GTK_BOX (top_hbox), display_box, TRUE, TRUE, 0);
 
 	/* Volume slider */
-	gcd->slider = gtk_vscale_new_with_range (-255.0, 0.0, 1.0);
+	gcd->slider = gtk_vscale_new_with_range (0.0, 255.0, 1.0);
 	gtk_scale_set_draw_value (GTK_SCALE (gcd->slider), FALSE);
+	gtk_range_set_inverted(GTK_RANGE(gcd->slider), TRUE);
 	gtk_box_pack_start (GTK_BOX (top_hbox), gcd->slider, FALSE, FALSE, 0);
 	
 	gtk_tooltips_set_tip (gcd->tooltips, GTK_WIDGET (gcd->slider),
