@@ -29,8 +29,10 @@
 G_BEGIN_DECLS
 
 /* create a new Profile Choose Dialog */
-GtkWidget*	gm_audio_profile_choose_new		();
-GMAudioProfile*	gm_audio_profile_choose_get_active	(GtkWidget *choose);
+GtkWidget*      gm_audio_profile_choose_new		();
+GMAudioProfile* gm_audio_profile_choose_get_active	(GtkWidget  *choose);
+gboolean        gm_audio_profile_choose_set_active	(GtkWidget  *choose,
+							 const char *id);
 
 G_END_DECLS
 
